aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorShelikhoo <xiaokangwang@outlook.com>2022-02-11 11:26:41 +0000
committerShelikhoo <xiaokangwang@outlook.com>2022-03-16 09:13:29 +0000
commit8d5998b7441eb9e213b8d86052e94a27d7656495 (patch)
tree41a0e8c17f55827df10d1235755e4de28bb12e33
parente3aeb5fe5b3cace5d482c2fa40e0b964711ab189 (diff)
downloadsnowflake-8d5998b7441eb9e213b8d86052e94a27d7656495.tar.gz
snowflake-8d5998b7441eb9e213b8d86052e94a27d7656495.zip
Harmonize identifiers to uTLS
-rw-r--r--client/lib/rendezvous.go12
-rw-r--r--client/lib/snowflake.go12
-rw-r--r--client/snowflake.go8
-rw-r--r--common/utls/client_hello_id.go2
4 files changed, 17 insertions, 17 deletions
diff --git a/client/snowflake.go b/client/snowflake.go
index a693ca6..76a5cc4 100644
--- a/client/snowflake.go
+++ b/client/snowflake.go
@@ -126,8 +126,8 @@ func main() {
frontDomain := flag.String("front", "", "front domain")
ampCacheURL := flag.String("ampcache", "", "URL of AMP cache to use as a proxy for signaling")
logFilename := flag.String("log", "", "name of log file")
- utlsClientHelloID := flag.String("utls-imitate", "", "type of TLS client to imitate with utls")
- utlsRemoveSNI := flag.Bool("utls-nosni", false, "remove SNI from client hello(ignored if uTLS is not used)")
+ uTLSClientHelloID := flag.String("utls-imitate", "", "type of TLS client to imitate with utls")
+ uTLSRemoveSNI := flag.Bool("utls-nosni", false, "remove SNI from client hello(ignored if uTLS is not used)")
logToStateDir := flag.Bool("log-to-state-dir", false, "resolve the log file relative to tor's pt state dir")
keepLocalAddresses := flag.Bool("keep-local-addresses", false, "keep local LAN address ICE candidates")
unsafeLogging := flag.Bool("unsafe-logging", false, "prevent logs from being scrubbed")
@@ -180,8 +180,8 @@ func main() {
ICEAddresses: iceAddresses,
KeepLocalAddresses: *keepLocalAddresses || *oldKeepLocalAddresses,
Max: *max,
- UTlsClientID: *utlsClientHelloID,
- UTlsRemoveSNI: *utlsRemoveSNI,
+ UTLSClientID: *uTLSClientHelloID,
+ UTLSRemoveSNI: *uTLSRemoveSNI,
}
// Begin goptlib client process.
diff --git a/common/utls/client_hello_id.go b/common/utls/client_hello_id.go
index e423cf3..8a13280 100644
--- a/common/utls/client_hello_id.go
+++ b/common/utls/client_hello_id.go
@@ -29,7 +29,7 @@ var clientHelloIDMap = map[string]utls.ClientHelloID{
var errNameNotFound = errors.New("client hello name is unrecognized")
-func NameToUTlsID(name string) (utls.ClientHelloID, error) {
+func NameToUTLSID(name string) (utls.ClientHelloID, error) {
normalizedName := strings.ToLower(name)
if id, ok := clientHelloIDMap[normalizedName]; ok {
return id, nil
diff --git a/client/lib/rendezvous.go b/client/lib/rendezvous.go
index dcf613c..1fc2a69 100644
--- a/client/lib/rendezvous.go
+++ b/client/lib/rendezvous.go
@@ -56,14 +56,14 @@ func createBrokerTransport() http.RoundTripper {
}
func NewBrokerChannel(broker, ampCache, front string, keepLocalAddresses bool) (*BrokerChannel, error) {
- return NewBrokerChannelWithUTlsSettings(broker, ampCache, front, keepLocalAddresses, "", false)
+ return NewBrokerChannelWithUTLSSettings(broker, ampCache, front, keepLocalAddresses, "", false)
}
// NewBrokerChannelWithUTlsSettings construct a new BrokerChannel, where:
// |broker| is the full URL of the facilitating program which assigns proxies
// to clients, and |front| is the option fronting domain.
-func NewBrokerChannelWithUTlsSettings(broker, ampCache, front string, keepLocalAddresses bool,
- utlsClientID string, removeSNI bool) (*BrokerChannel, error) {
+func NewBrokerChannelWithUTLSSettings(broker, ampCache, front string, keepLocalAddresses bool,
+ uTLSClientID string, removeSNI bool) (*BrokerChannel, error) {
log.Println("Rendezvous using Broker at:", broker)
if ampCache != "" {
log.Println("Through AMP cache at:", ampCache)
@@ -74,8 +74,8 @@ func NewBrokerChannelWithUTlsSettings(broker, ampCache, front string, keepLocalA
brokerTransport := createBrokerTransport()
- if utlsClientID != "" {
- utlsClientHelloID, err := utlsutil.NameToUTlsID(utlsClientID)
+ if uTLSClientID != "" {
+ utlsClientHelloID, err := utlsutil.NameToUTLSID(uTLSClientID)
if err != nil {
return nil, fmt.Errorf("unable to create broker channel: %v", err)
}
@@ -56,14 +56,14 @@ func createBrokerTransport() http.RoundTripper {
}
-// NewBrokerChannelWithUTlsSettings construct a new BrokerChannel, where:
+// NewBrokerChannelWithUTLSSettings construct a new BrokerChannel, where:
// |broker| is the full URL of the facilitating program which assigns proxies
// to clients, and |front| is the option fronting domain.
diff --git a/client/lib/snowflake.go b/client/lib/snowflake.go
index e309b44..1c6c381 100644
--- a/client/lib/snowflake.go
+++ b/client/lib/snowflake.go
@@ -97,12 +97,12 @@ type ClientConfig struct {
// Max is the maximum number of snowflake proxy peers that the client should attempt to
// connect to. Defaults to 1.
Max int
// UTlsClientID is the type of user application that snowflake should imitate.
// If an empty value is provided, it will use Go's default TLS implementation
- UTlsClientID string
- // UTlsRemoveSNI is the flag to control whether SNI should be removed from Client Hello
+ UTLSClientID string
+ // UTLSRemoveSNI is the flag to control whether SNI should be removed from Client Hello
// when uTLS is used.
- UTlsRemoveSNI bool
+ UTLSRemoveSNI bool
}
// NewSnowflakeClient creates a new Snowflake transport client that can spawn multiple
@@ -131,9 +131,9 @@ func NewSnowflakeClient(config ClientConfig) (*Transport, error) {
}
// Rendezvous with broker using the given parameters.
- broker, err := NewBrokerChannelWithUTlsSettings(
+ broker, err := NewBrokerChannelWithUTLSSettings(
config.BrokerURL, config.AmpCacheURL, config.FrontDomain,
- config.KeepLocalAddresses, config.UTlsClientID, config.UTlsRemoveSNI)
+ config.KeepLocalAddresses, config.UTLSClientID, config.UTLSRemoveSNI)
if err != nil {
return nil, err
}
@@ -97,12 +97,12 @@ type ClientConfig struct {
// connect to. Defaults to 1.
Max int
- // UTlsClientID is the type of user application that snowflake should imitate.
+ // UTLSClientID is the type of user application that snowflake should imitate.
// If an empty value is provided, it will use Go's default TLS implementation